#!/usr/bin/env python

# Written by Tavmjong Bah

import inkex
import re
import os
from lxml import etree

class C(inkex.Effect):
  def __init__(self):
    inkex.Effect.__init__(self)
    self.OptionParser.add_option("-w", "--width",  action="store", type="int",    dest="desktop_width",  default="100", help="Custom width")
    self.OptionParser.add_option("-z", "--height", action="store", type="int",    dest="desktop_height", default="100", help="Custom height")

  def effect(self):

    width  = self.options.desktop_width
    height = self.options.desktop_height
    path = os.path.dirname(os.path.realpath(__file__))
    self.document = etree.parse(os.path.join(path, "tesselation.svg"))
    root = self.document.getroot()
    root.set("id", "SVGRoot")
    root.set("width",  str(width) + 'px')
    root.set("height", str(height) + 'px')
    root.set("viewBox", "0 0 " + str(width) + " " + str(height) )

    xpathStr = '//svg:use[@id="sampleTile"]'
    sampleTile = root.xpath(xpathStr, namespaces=inkex.NSS)
    if sampleTile != []:
        sampleTile[0].set("transform", "translate(" + str(width * 6) + ",-" + str(height) + ")")
        
        
    xpathStr = '//svg:use[@id="clipPathRect"]'
    clipPathRect = root.xpath(xpathStr, namespaces=inkex.NSS)
    if clipPathRect != []:
        clipPathRect[0].set("transform", "translate(" + str((width*3)) + "," + str(height) +")")

    xpathStr = '//svg:tspan[@id="infoText"]'
    infoText = root.xpath(xpathStr, namespaces=inkex.NSS)
    if infoText != []:
        infoText[0].text = infoText[0].text.replace("100x100", str(width) + "x" + str(height))

    xpathStr = '//svg:use[@id="backgroundTessela"]'
    backgroundTessela = root.xpath(xpathStr, namespaces=inkex.NSS)
    if backgroundTessela != []:
        backgroundTessela[0].set("transform", "translate(-" + str(width * 2) + ",0)")

    xpathStr = '//svg:rect[@id="cuadroTessela"]'
    cuadroTessela = root.xpath(xpathStr, namespaces=inkex.NSS)
    if cuadroTessela != []:
        cuadroTessela[0].set("width", str(width))
        cuadroTessela[0].set("height", str(height))
        cuadroTessela[0].set("y", "-" + str(height*2))

    xpathStr = '//svg:use[@id="cuadroTesselaDisenador"]'
    cuadroTesselaDisenador = root.xpath(xpathStr, namespaces=inkex.NSS)
    if cuadroTesselaDisenador != []:
        cuadroTesselaDisenador[0].set("transform", "translate(" + str(width * 3) + "," + str(height) + ")")

    xpathStr = '//svg:g[@id="designZone"]'
    designZone = root.xpath(xpathStr, namespaces=inkex.NSS)
    if designZone != []:
        designZone[0].set("transform", "translate(" + str((width*5)) + ",0)scale(" + str(((width+height)/2)/100.) + ")")

    xpathStr = '//svg:g[@id="tesselaResult"]'
    tesselaResult = root.xpath(xpathStr, namespaces=inkex.NSS)
    if tesselaResult != []:
        tesselaResult[0].set("transform", "translate(-" + str((width * 3)) + "," + str(height) + ")")

    xpathStr = '//svg:use[@id="tesselaTileBackground"]'
    tesselaTileBackground = root.xpath(xpathStr, namespaces=inkex.NSS)
    if tesselaTileBackground != []:
        tesselaTileBackground[0].set("transform", "matrix(3,0,0,3," + str((width * 2)) + "," + str(height * 4) + ")")
        tesselaTileBackground[0].set("width", str(width*3))
        tesselaTileBackground[0].set("height", str(height*3))

    xpathStr = '//svg:use[@id="tessela1"]'
    tessela1 = root.xpath(xpathStr, namespaces=inkex.NSS)
    if tessela1 != []:
        tessela1[0].set("transform", "translate(" + str(-width) + "," + str(-height) + ")")

    xpathStr = '//svg:use[@id="tessela2"]'
    tessela2 = root.xpath(xpathStr, namespaces=inkex.NSS)
    if tessela2 != []:
        tessela2[0].set("transform", "translate(0," + str(-height) +")" )

    xpathStr = '//svg:use[@id="tessela3"]'
    tessela3 = root.xpath(xpathStr, namespaces=inkex.NSS)
    if tessela3 != []:
        tessela3[0].set("transform", "translate(" + str(width) + "," + str(-height) + ")" )

    xpathStr = '//svg:use[@id="tessela4"]'
    tessela4 = root.xpath(xpathStr, namespaces=inkex.NSS)
    if tessela4 != []:
        tessela4[0].set("transform", "translate(" + str(-width) + ",0)" )

    xpathStr = '//svg:use[@id="tessela5"]'
    tessela5 = root.xpath(xpathStr, namespaces=inkex.NSS)
    if tessela5 != []:
        tessela5[0].set("transform", "translate(0,0)" )

    xpathStr = '//svg:use[@id="tessela6"]'
    tessela6 = root.xpath(xpathStr, namespaces=inkex.NSS)
    if tessela6 != []:
        tessela6[0].set("transform", "translate(" + str(width) + ",0)" )

    xpathStr = '//svg:use[@id="tessela7"]'
    tessela7 = root.xpath(xpathStr, namespaces=inkex.NSS)
    if tessela7 != []:
        tessela7[0].set("transform", "translate(" + str(-width) + "," + str(height) + ")" )

    xpathStr = '//svg:use[@id="tessela8"]'
    tessela8 = root.xpath(xpathStr, namespaces=inkex.NSS)
    if tessela8 != []:
        tessela8[0].set("transform", "translate(0," + str(height) + ")" )

    xpathStr = '//svg:use[@id="tessela9"]'
    tessela9 = root.xpath(xpathStr, namespaces=inkex.NSS)
    if tessela9 != []:
        tessela9[0].set("transform", "translate(" + str(width) + "," + str(height) + ")" )

    xpathStr = '//svg:use[@id="sampleTessela1"]'
    sampleTessela1 = root.xpath(xpathStr, namespaces=inkex.NSS)
    if sampleTessela1 != []:
        sampleTessela1[0].set("transform", "translate(" + str(-width) + "," + str(-height) + ")")

    xpathStr = '//svg:use[@id="sampleTessela2"]'
    sampleTessela2 = root.xpath(xpathStr, namespaces=inkex.NSS)
    if sampleTessela2 != []:
        sampleTessela2[0].set("transform", "translate(0," + str(-height) +")" )

    xpathStr = '//svg:use[@id="sampleTessela3"]'
    sampleTessela3 = root.xpath(xpathStr, namespaces=inkex.NSS)
    if sampleTessela3 != []:
        sampleTessela3[0].set("transform", "translate(" + str(width) + "," + str(-height) + ")" )

    xpathStr = '//svg:use[@id="sampleTessela4"]'
    sampleTessela4 = root.xpath(xpathStr, namespaces=inkex.NSS)
    if sampleTessela4 != []:
        sampleTessela4[0].set("transform", "translate(" + str(-width) + ",0)" )

    xpathStr = '//svg:use[@id="sampleTessela5"]'
    sampleTessela5 = root.xpath(xpathStr, namespaces=inkex.NSS)
    if sampleTessela5 != []:
        sampleTessela5[0].set("transform", "translate(0,0)" )

    xpathStr = '//svg:use[@id="sampleTessela6"]'
    sampleTessela6 = root.xpath(xpathStr, namespaces=inkex.NSS)
    if sampleTessela6 != []:
        sampleTessela6[0].set("transform", "translate(" + str(width) + ",0)" )

    xpathStr = '//svg:use[@id="sampleTessela7"]'
    sampleTessela7 = root.xpath(xpathStr, namespaces=inkex.NSS)
    if sampleTessela7 != []:
        sampleTessela7[0].set("transform", "translate(" + str(-width) + "," + str(height) + ")" )

    xpathStr = '//svg:use[@id="sampleTessela8"]'
    sampleTessela8 = root.xpath(xpathStr, namespaces=inkex.NSS)
    if sampleTessela8 != []:
        sampleTessela8[0].set("transform", "translate(0," + str(height) + ")" )

    xpathStr = '//svg:use[@id="sampleTessela9"]'
    sampleTessela9 = root.xpath(xpathStr, namespaces=inkex.NSS)
    if sampleTessela9 != []:
        sampleTessela9[0].set("transform", "translate(" + str(width) + "," + str(height) + ")" )

    xpathStr = '//svg:g[@id="tesselaPreview"]'
    tesselaPreview = root.xpath(xpathStr, namespaces=inkex.NSS)
    if tesselaPreview != []:
        tesselaPreview[0].set("transform", "translate(0," + str(height*2) + ")" )

    xpathStr = '//svg:g[@id="helperLayer"]'
    helperLayer = root.xpath(xpathStr, namespaces=inkex.NSS)
    if helperLayer != []:
        helperLayer[0].set("transform", "scale(" + str(width/100.) + "," + str(height/100.) + ")" )

    xpathStr = '//svg:use[@id="tesselaGenerator" or id="tesselaPreviewFast"]'
    tesselaGenerator = root.xpath(xpathStr, namespaces=inkex.NSS)
    if tesselaGenerator != []:
        tesselaGenerator[0].set("{http://www.inkscape.org/namespaces/inkscape}tile-cx", str((width*3)/2))
        tesselaGenerator[0].set("{http://www.inkscape.org/namespaces/inkscape}tile-cy", str(height/2))
        tesselaGenerator[0].set("{http://www.inkscape.org/namespaces/inkscape}tile-w", str(width))
        tesselaGenerator[0].set("{http://www.inkscape.org/namespaces/inkscape}tile-h", str(height))
        tesselaGenerator[0].set("{http://www.inkscape.org/namespaces/inkscape}tile-x0", str(width))
        tesselaGenerator[0].set("{http://www.inkscape.org/namespaces/inkscape}tile-y0", str(height))
        tesselaGenerator[0].set("width", str(width))
        tesselaGenerator[0].set("height", str(height))

    namedview = root.find(inkex.addNS('namedview', 'sodipodi'))
    if namedview is None:
        namedview = inkex.etree.SubElement( root, inkex.addNS('namedview', 'sodipodi') );
     
    namedview.set(inkex.addNS('document-units', 'inkscape'), 'px')

    namedview.set(inkex.addNS('cx',        'inkscape'), str((width*8)/2.0) )
    namedview.set(inkex.addNS('cy',        'inkscape'), "0" )
    namedview.set(inkex.addNS('zoom',        'inkscape'), str(0.5 / (((width+height)/2)/100.)) )

c = C()
c.affect()
